@@ -5,7 +5,7 @@ import logging
 import posixpath
 import urllib.parse
 import xml.etree.ElementTree as etree
-from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Iterator, List, Optional, Set, Tuple, Union, cast
 
 import markdown
 import markdown.extensions
@@ -19,7 +19,11 @@ from mkdocs_literate_nav import exceptions
 log = logging.getLogger(f"mkdocs.plugins.{__name__}")
 log.addFilter(mkdocs.utils.warning_filter)
 
-_unescape = markdown.postprocessors.UnescapePostprocessor().run
+_unescape: Callable[[str], str]
+try:
+    _unescape = markdown.treeprocessors.UnescapeTreeprocessor().unescape  # type: ignore
+except AttributeError:
+    _unescape = markdown.postprocessors.UnescapePostprocessor().run
 
 
 NavItem = Union[str, Dict[Optional[str], Union[str, Any]]]
@@ -37,7 +41,7 @@ class NavParser:
         self.get_nav_for_dir = get_nav_for_dir
         self.globber = globber
         self.implicit_index = implicit_index
-        self.seen_items = set()
+        self.seen_items: Set[str] = set()
         self._warn = functools.lru_cache()(log.warning)
 
     def markdown_to_nav(self, roots: Tuple[str, ...] = (".",)) -> Nav:
@@ -47,23 +51,25 @@ class NavParser:
         if dir_nav:
             nav_file_name, md = dir_nav
             markdown.markdown(md, extensions=[ext])
-            if ext.nav:
-                self.seen_items.add(posixpath.normpath(posixpath.join(root, nav_file_name)))
+            if ext.nav is not None:
+                self_path = posixpath.normpath(posixpath.join(root, nav_file_name))
+                if not (self.implicit_index and self_path == self.globber.find_index(root)):
+                    self.seen_items.add(self_path)
         first_item = None
-        if ext.nav and self.implicit_index and root != ".":
+        if ext.nav is not None and self.implicit_index:
             first_item = self.globber.find_index(root)
             if first_item:
                 first_item = Wildcard(root, "/" + first_item, fallback=False)
-        if not ext.nav:
+        if ext.nav is None:
             log.debug(f"Navigation for {root!r} will be inferred.")
             return self._resolve_wildcards([Wildcard(root, "*", fallback=False)], roots)
         return self._resolve_wildcards(self._list_element_to_nav(ext.nav, root, first_item), roots)
 
     def _list_element_to_nav(
-        self, section: etree.Element, root: str, first_item: Optional[str] = None
+        self, section: etree.Element, root: str, first_item: Union["Wildcard", str, None] = None
     ):
         assert section.tag in _LIST_TAGS
-        result = []
+        result: List[Union[Wildcard, str, list, Dict[str, Union[Wildcard, str, list]]]] = []
         if first_item is not None:
             if isinstance(first_item, str):
                 self.seen_items.add(first_item)
@@ -71,18 +77,21 @@ class NavParser:
         for item in section:
             assert item.tag == "li"
             out_title = item.text
-            out_item = None
+            out_item: Union[Wildcard, str, list, None] = None
 
             children = _iter_children_without_tail(item)
             try:
                 child = next(children)
                 if not out_title and child.tag == "a":
                     link = child.get("href")
-                    out_item = self._resolve_string_item(root, link)
-                    out_title = _unescape("".join(child.itertext()))
+                    if link:
+                        out_item = self._resolve_string_item(root, link)
+                        out_title = _unescape("".join(child.itertext()))
                     child = next(children)
                 if child.tag in _LIST_TAGS:
-                    out_item = self._list_element_to_nav(child, root, out_item)
+                    out_item = self._list_element_to_nav(
+                        child, root, cast(Union[Wildcard, str, None], out_item)
+                    )
                     child = next(children)
             except StopIteration:
                 error = ""
@@ -99,9 +108,11 @@ class NavParser:
             if error:
                 raise LiterateNavParseError(error, item)
 
+            assert out_item is not None
             if type(out_item) in (str, list, DirectoryWildcard) and out_title is not None:
-                out_item = {out_title: out_item}
-            result.append(out_item)
+                result.append({out_title: out_item})
+            else:
+                result.append(out_item)
         return result
 
     def _resolve_string_item(self, root: str, link: str) -> Union["Wildcard", str]:
@@ -150,7 +161,7 @@ class NavParser:
                     resolved.append(entry)
                 continue
 
-            assert not isinstance(entry, DirectoryWildcard)
+            assert not isinstance(entry, (DirectoryWildcard, list))
             if not isinstance(entry, Wildcard):
                 resolved.append(entry)
                 continue
@@ -262,7 +273,7 @@ class Wildcard:
         self.value = norm
         self.fallback = path_parts[-1] if fallback else None
 
-    def __str__(self):
+    def __repr__(self):
         return f"{type(self).__name__}({self.value!r})"
 
 
