@@ -14,9 +14,10 @@ import mkdocs.structure.nav
 import mkdocs.structure.pages
 
 try:
-    from mkdocs.exceptions import PluginError
+    from mkdocs.plugins import event_priority
 except ImportError:
-    PluginError = SystemExit
+    event_priority = lambda priority: lambda f: f  # No-op fallback
+
 
 from mkdocs_literate_nav import parser
 
@@ -24,13 +25,20 @@ log = logging.getLogger(f"mkdocs.plugins.{__name__}")
 log.addFilter(mkdocs.utils.warning_filter)
 
 
+class _PluginConfig:
+    nav_file = mkdocs.config.config_options.Type(str, default="SUMMARY.md")
+    implicit_index = mkdocs.config.config_options.Type(bool, default=False)
+
+
 class LiterateNavPlugin(mkdocs.plugins.BasePlugin):
-    config_scheme = (
-        ("nav_file", mkdocs.config.config_options.Type(str, default="SUMMARY.md")),
-        ("implicit_index", mkdocs.config.config_options.Type(bool, default=False)),
+    config_scheme = tuple(
+        (k, v)
+        for k, v in _PluginConfig.__dict__.items()
+        if isinstance(v, mkdocs.config.config_options.BaseConfigOption)
     )
 
-    def on_files(self, files: mkdocs.structure.files.Files, config: mkdocs.config.Config):
+    @event_priority(-100)  # Run last
+    def on_files(self, files: mkdocs.structure.files.Files, config: mkdocs.config.Config) -> None:
         config["nav"] = resolve_directories_in_nav(
             config["nav"],
             files,
@@ -44,7 +52,7 @@ class LiterateNavPlugin(mkdocs.plugins.BasePlugin):
         nav: mkdocs.structure.nav.Navigation,
         config: mkdocs.config.Config,
         files: mkdocs.structure.files.Files,
-    ):
+    ) -> None:
         if files != getattr(self, "_files", None):
             log.warning(
                 "The literate-nav plugin created the nav based on files that were subsequently modified by another MkDocs plugin! "
@@ -122,6 +130,7 @@ class MkDocsGlobber:
                         yield str(path)[1:]
 
     def find_index(self, root: str) -> Optional[str]:
-        root = PurePosixPath("/", root)
-        if root in self.index_dirs:
-            return str(self.index_dirs[root])[1:]
+        root_path = PurePosixPath("/", root)
+        if root_path in self.index_dirs:
+            return str(self.index_dirs[root_path])[1:]
+        return None
